@@ -9,20 +9,19 @@ module Serverspec::Type
     def [](key)
       value = inspection
       key.split('.').each do |k|
-        value = value[k]
+        is_index = k.start_with?('[') && k.end_with?(']')
+        value = value[is_index ? k[1..-2].to_i : k]
       end
       value
     end
 
     def inspection
-      return @inspection if @inspection
-      @inspection = ::MultiJson.load(get_inspection.stdout)[0]
+      @inspection ||= ::MultiJson.load(get_inspection.stdout)[0]
     end
 
     private
     def get_inspection
-      return @get_inspection if @get_inspection
-      @get_inspection = @runner.run_command("docker inspect #{@name}")
+      @get_inspection ||= @runner.run_command("docker inspect #{@name}")
     end
   end
 end
