@@ -9,3 +9,8 @@ end
 describe group('root') do
   it { should have_gid 0 }
 end
+
+describe group('root') do
+  its(:gid) { should == 0 }
+  its(:gid) { should < 10 }
+end
